.. Bedrock Server Manager Bedrock Server Core documentation file

Bedrock Server Core Documentation
=================================

.. autoclass:: bedrock_server_manager.BedrockServer
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members: bedrock_server_manager.core.server.base_server_mixin.BedrockServerBaseMixin, bedrock_server_manager.core.server.installation_mixin.ServerInstallationMixin, bedrock_server_manager.core.server.state_mixin.ServerStateMixin, bedrock_server_manager.core.server.process_mixin.ServerProcessMixin, bedrock_server_manager.core.server.world_mixin.ServerWorldMixin, bedrock_server_manager.core.server.addon_mixin.ServerAddonMixin, bedrock_server_manager.core.server.backup_restore_mixin.ServerBackupMixin, bedrock_server_manager.core.server.systemd_mixin.ServerSystemdMixin, bedrock_server_manager.core.server.player_mixin.ServerPlayerMixin, bedrock_server_manager.core.server.windows_service_mixin.ServerWindowsServiceMixin, bedrock_server_manager.core.server.config_management_mixin.ServerConfigManagementMixin, bedrock_server_manager.core.server.install_update_mixin.ServerInstallUpdateMixin
   :member-order: bysource

   .. automethod:: __init__